# 4장 그레이들 입문하기

## 리스트 4-1――build.gradle
```
apply plugin: 'java'

repositories {
    jcenter()
}

dependencies {
    compile 'org.slf4j:slf4j-api:1.7.21'
    testCompile 'junit:junit:4.12'
}
```

## 리스트 4-2――settings.gradle
```
rootProject.name = 'gradle-app'
```

## 리스트 4-3
```
public class Library {
    public boolean someLibraryMethod() {
        return true;
    }
}
```

## 리스트 4-4
```
import org.junit.Test;
import static org.junit.Assert.*;

public class LibraryTest {
    @Test public void testSomeLibraryMethod() {
        Library classUnderTest = new Library();
        assertTrue("someLibraryMethod should return 'true'",
            classUnderTest.someLibraryMethod());
    }
}
```

## 리스트 4-5――build.gradle
```
group 'com.tuyano'
version '1.0-SNAPSHOT'

apply plugin: 'java'

sourceCompatibility = 1.5

repositories {
    mavenCentral()
}

dependencies {
    testCompile group: 'junit', name: 'junit', version: '4.11'
}
```

## 리스트 4-6――settings.gradle
```
rootProject.name = 'gradle-intellij-app'
```

## 리스트 4-7――build.gradle
```
apply plugin: 'java'

sourceCompatibility = '1.8'
[compileJava, compileTestJava]*.options*.encoding = 'UTF-8'

if (!hasProperty('mainClass')) {
    ext.mainClass = 'com.tuyano.gradle.App'
}

repositories {
    mavenCentral()
}

dependencies {
    testCompile group: 'junit', name: 'junit', version: '4.10'
}
```

## 리스트 4-8――settings.gradle
```
rootProject.name = 'nb-gradle-app'
```

## 리스트 4-9
```
task hello {
    doLast {
        println();
        println("====================");
        println("Welcome to Gradle!");
        println("====================");
        println();
    }
}
```

## 리스트 4-10
```
task hello {
    doLast {
        println("==========LAST==========");
        println(" This is doLast action!");
        println("==========LAST==========");
    }
    doFirst {
        println();
        println("==========START==========");
        println(" This is doFirst action!");
        println("==========START==========");
    }
}
```

## 리스트 4-11
```
task helo {
    doLast {
        def total = 0;
        for(def i in 1..num.toInteger()){
            total += i;
        }
        println("total: " + total);
    }
}
```

## 리스트 4-12
```
def arr = ["one","two","three","four","five"];
arr.each {s ->
    task "$s" {
        doLast {
            println("this is $s task.");
        }
    }
}
```

## 리스트 4-13
```
apply plugin: 'java'
```

## 리스트 4-14
```
apply plugin: 'java'

task doit(dependsOn: [compileJava, jar]) {
    doLast {
        println "*** compiled and created Jar! ***"
    }
}
```

## 리스트 4-15
```
task doit(dependsOn: [compileJava, jar]) {
    doLast {
        println "*** compile now! ***"
        tasks.compileJava.execute()
        println "*** create jar! ***"
        tasks.jar.execute()
    }
}
```

## 리스트 4-16
```
package com.tuyano.gradle;

public class App {

    public static void main(String[] args){
        App app = new App();
        System.out.println("=====App class=====");
        app.showMessage("Taro");
        app.showMessage("Hanako");
        System.out.println("=====App class=====");
    }

    public boolean showMessage(String name){
        try {
        System.out.println(this.getMessage(name));
        } catch(Exception e){
            System.out.println("[ERR: " + e.getMessage() + "]");
            return false;
        } finally {
            return true;
        }
    }

    public String getMessage(String name) throws Exception {
        if (name == null || name == ""){
            throw new Exception("no name!!");
        }
        return "Hi," + name + ". welcome to gradle world!";
    }
}
```

## 리스트 4-17
```
apply plugin: 'java'
apply plugin: 'application'

mainClassName = "com.tuyano.gradle.App"

task doit(dependsOn:[jar, run]) {
    doLast {
        println("*** do it! ***")
    }
}
```

## 리스트 4-18
```
package com.tuyano.gradle;

import org.junit.Test;
import static org.junit.Assert.*;

public class AppTest {

    @Test
    public void testApp() {
        String name = "hoge";
        App app = new App();
        assertNotNull(app);
        assertTrue(app.showMessage(name));
        try {
            assertTrue(app.getMessage(name).contains(name));
        } catch(Exception e){
            e.printStackTrace();
        }
    }

}
```

## 리스트 4-19
```
apply plugin: 'java'
apply plugin: 'application'

mainClassName = "com.tuyano.gradle.App"

repositories {
    jcenter()
}

dependencies {
    testCompile 'junit:junit:4.12'
}
```

## 리스트 4-20
```
apply plugin: 'java'
apply plugin: 'application'

mainClassName = "com.tuyano.gradle.App"

repositories {
    mavenCentral()
}

dependencies {
    testCompile group: 'junit', name: 'junit', version: '4.12'
}
```